CCL: /home/chisarie/Documents/lsst_ccl/CCL/tests/ccl_test_massfunc.c File Reference

CCL

Macros | Functions
ccl_test_massfunc.c File Reference
`#include "ccl.h"`
`#include "ccl_massfunc.h"`
`#include "ctest.h"`
`#include <stdio.h>`
`#include <math.h>`

## Macros
#define | SIGMA_TOLERANCE 1e-4
#define | INVSIGMA_TOLERANCE 5e-3
#define | MASSFUNC_TOLERANCE 5e-3

## Functions
| CTEST_DATA (massfunc)
| CTEST_SETUP (massfunc)
| CTEST2 (massfunc, model_1)

## Macro Definition Documentation

## ◆ INVSIGMA_TOLERANCE

#define INVSIGMA_TOLERANCE 5e-3

## ◆ MASSFUNC_TOLERANCE

#define MASSFUNC_TOLERANCE 5e-3

## ◆ SIGMA_TOLERANCE

#define SIGMA_TOLERANCE 1e-4

## Function Documentation

## ◆ CTEST2()

CTEST2 | ( | massfunc | ,
|  | model_1 |
| ) |  |

## ◆ CTEST_DATA()

CTEST_DATA | ( | massfunc |  | ) |

## ◆ CTEST_SETUP()

CTEST_SETUP | ( | massfunc |  | ) |